@@ -1,3 +1,3 @@
 from bergen.clients.default import Bergen
 from bergen.comfort import use
-from bergen.actors.utils import log
\ No newline at end of file
+from bergen.actors.utils import log, useApp, useUser
\ No newline at end of file
