@@ -8,7 +8,7 @@ from bergen.legacy.utils import get_running_loop
 assign_handler_context  = contextvars.ContextVar('assign_handler', default=None)
 provide_handler_context = contextvars.ContextVar("provide_handler", default=None)
 
-bounce_context = contextvars.ContextVar("context_context", default=None)
+bounce_context = contextvars.ContextVar("bounce_context", default=None)
 queue_context = contextvars.ContextVar("queue_context", default=None)
 
 
@@ -44,6 +44,8 @@ def log(message: str, level: DebugLevel = DebugLevel.INFO):
     Returns:
         [Future]: Returns a future if currently running in an event loop
     """
+    message = str(message)
+
     try:
         event_loop = get_running_loop()
     except RuntimeError:
