@@ -14,17 +14,11 @@ from functools import partial
 import json
 from bergen.console import console
 import asyncio
-try:
-    from asyncio import create_task
-except ImportError:
-    #python 3.6 fix
-    create_task = asyncio.ensure_future
-
 
 import websockets
 from bergen.schema import AssignationStatus, Node, ProvisionStatus, Template
 from bergen.models import Pod
-
+from bergen.legacy.utils import create_task
 
 
 logger = logging.getLogger(__name__)
