@@ -21,11 +21,11 @@ class AIOHttpWard(ServiceWard):
 
     async def negotiate(self):
         query_node = """
-            mutation Negotiate {
-                negotiate
+            mutation Negotiate($internal: Boolean) {
+                    negotiate(internal: $internal)
             }
         """
-        async with self.async_session.post(self._graphql_endpoint, json={"query": query_node}) as resp:
+        async with self.async_session.post(self._graphql_endpoint, json={"query": query_node, "variables": self.client.config.dict()}) as resp:
             result = await resp.json() 
             return result["data"]["negotiate"]
             
